syntax = "proto3";

package commons;

enum VariantType {
  NONE = 0;
  DOUBLE = 1;
  INT = 2;
  STRING = 3;
  PARQUET = 4;
  ARROW = 5;
  JSON = 6;
}

message Variant {
  VariantType type = 2;
  bytes value = 3;
}

message Argument {
  uint32 position = 1;
  Variant data = 2;
}

message KwArgument {
  string keyword = 1;
  Variant data = 2;
}

message Status {
  string code = 1;  // "SUCCESS", "INVALID_ARGUMENT", etc.
  string message = 2;
}
